<?php 

/**
 * Build theme options
 * Uses the Ebor_Options class found in the ebor-framework plugin
 * Panels are WP 4.0+!!!
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if( class_exists('Ebor_Options') ){
	$ebor_options = new Ebor_Options;
	
	/**
	 * Variables
	 */
	$theme = wp_get_theme();
	$theme_name = $theme->get( 'Name' );
	$social_options = ebor_get_social_icons();
	$footer_default = 'modify this message from "appearance => customise"';
	$portfolio_layouts = array_flip(ebor_get_portfolio_layouts());
	$blog_layouts = array_flip(ebor_get_blog_layouts());
	$header_layouts = ebor_get_header_layouts();
	$available_pages = get_pages();
	foreach( $available_pages as $available_page ){
		$page_choices[$available_page->ID] = $available_page->post_title;
	}
	$page_titles = array(
		'light' => 'Light Background',
		'dark' => 'Dark Background',
		'image' => 'Image Background',
		'none' => 'No Page Title'
	);
	
	/**
	 * Default stuff
	 * 
	 * Each of these is a default option that appears in each theme, demo data, favicons and a custom css input
	 * 
	 * @since 1.0.0
	 * @author tommusrhodus
	 */
	$ebor_options->add_panel( $theme_name . ': Demo Data', 5, '');
	$ebor_options->add_panel( $theme_name . ': Styling Settings', 205, 'All of the controls in this section directly relate to the styling page of ' . $theme_name);
	$ebor_options->add_section('demo_data_section', 'Import Demo Data', 10, $theme_name . ': Demo Data', '<strong>Please read this before importing demo data via this control:</strong><br /><br />The demo data this will install includes images from my demo site with <strong>heavy blurring applied</strong> this is due to licensing restrictions. Simply replace these images with your own.<br /><br />Note that this process can take up to 15mins on slower servers, go make a cup of tea. If you havn\'t had a notification in 30mins, use the fallback method outlined in the written documentation.<br /><br />');
	$ebor_options->add_section('favicon_section', 'Favicons', 30, $theme_name . ': Styling Settings');
	$ebor_options->add_section('custom_css_section', 'Custom CSS', 40, $theme_name . ': Styling Settings');
	$ebor_options->add_setting('image', 'custom_favicon', 'Custom Favicon Upload (Use .png)', 'favicon_section', '', 10);
	$ebor_options->add_setting('image', 'mobile_favicon', 'Mobile Favicon Upload (Use .png)', 'favicon_section', '', 15);
	$ebor_options->add_setting('image', '72_favicon', '72x72px Favicon Upload (Use .png)', 'favicon_section', '', 20);
	$ebor_options->add_setting('image', '114_favicon', '114x114px Favicon Upload (Use .png)', 'favicon_section', '', 25);
	$ebor_options->add_setting('image', '144_favicon', '144x144px Favicon Upload (Use .png)', 'favicon_section', '', 30);
	$ebor_options->add_setting('demo_import', 'demo_import', 'Import Demo Data', 'demo_data_section', '', 10);
	$ebor_options->add_setting('textarea', 'custom_css', 'Custom CSS', 'custom_css_section', '', 30);
	
	/**
	 * Panels
	 * 
	 * add_panel($name, $priority, $description)
	 * 
	 * @since 1.0.0
	 * @author tommusrhodus
	 */
	$ebor_options->add_panel( $theme_name . ': Header Settings', 215, 'All of the controls in this section directly relate to the header and logos of ' . $theme_name);
	$ebor_options->add_panel( $theme_name . ': Blog Settings', 225, 'All of the controls in this section directly relate to the control of blog items within ' . $theme_name);
	$ebor_options->add_panel( $theme_name . ': Portfolio Settings', 230, 'All of the controls in this section directly relate to the control of portfolio items within ' . $theme_name);
	$ebor_options->add_panel( $theme_name . ': Footer Settings', 290, 'All of the controls in this section directly relate to the control of the footer within ' . $theme_name);
	
	/**
	 * Sections
	 * 
	 * add_section($name, $title, $priority, $panel, $description)
	 * 
	 * @since 1.0.0
	 * @author tommusrhodus
	 */
	//Styling Sections
	$ebor_options->add_section('site_section', 'Site Layout', 1, $theme_name . ': Styling Settings');
	
	//Blog Sections
	$ebor_options->add_section('blog_settings', 'Blog Settings', 1, $theme_name . ': Blog Settings');
	$ebor_options->add_section('blog_text_section', 'Blog Texts', 5, $theme_name . ': Blog Settings');
	$ebor_options->add_section('blog_layout_section', 'Blog Layout', 10, $theme_name . ': Blog Settings');
	
	$ebor_options->add_section('team_settings', 'Team Settings', 180, false);
	
	$ebor_options->add_setting('input', 'team_title', 'Team Archives: Title', 'team_settings', 'From My team', 20);
	$ebor_options->add_setting('select', 'team_page_title_layout', 'Team Title Layout', 'team_settings', 'light', 45, $page_titles);
	$ebor_options->add_setting('image', 'team_page_title_image', 'Team Title Background', 'team_settings', '', 40);
	
	//Portfolio Sections
	$ebor_options->add_section('portfolio_text_section', 'Portfolio Texts', 5, $theme_name . ': Portfolio Settings');
	$ebor_options->add_section('portfolio_layout_section', 'Portfolio Layout', 10, $theme_name . ': Portfolio Settings');
	$ebor_options->add_section('single_portfolio_layout_section', 'Portfolio-Single Layout', 10, $theme_name . ': Portfolio Settings');
	
	//Header Settings
	$ebor_options->add_section('header_layout_section', 'Header Layout', 5, $theme_name . ': Header Settings', 'This setting controls the theme header site-wide. If you need to you can override this setting on specific posts and pages from within that posts edit screen.');
	$ebor_options->add_section('logo_settings_section', 'Logo Settings', 10, $theme_name . ': Header Settings');
	$ebor_options->add_section('header_icons_section', 'Header Icon Settings', 15, $theme_name . ': Header Settings');
	$ebor_options->add_section('footer_icons_section', 'Footer Icon Settings', 15, $theme_name . ': Footer Settings');
	$ebor_options->add_section('subheader_settings_section', 'Sub-Header Settings', 30, $theme_name . ': Header Settings');
	
	//Footer Settings
	$ebor_options->add_section('subfooter_settings_section', 'Sub-Footer Settings', 30, $theme_name . ': Footer Settings');
	
	
	//Header Options
	$ebor_options->add_setting('select', 'header_layout', 'Global Header Layout', 'header_layout_section', 'dark-transparent', 5, $header_layouts);
	
	//Subheader Options
	$ebor_options->add_setting('input', 'header_phone', 'Phone No.', 'subheader_settings_section', '+00 (123) 456 78 90 ', 10);
	$ebor_options->add_setting('input', 'header_email', 'Email', 'subheader_settings_section', 'first.last@email.com', 20);
	
	//Colour Options
	$ebor_options->add_setting('color', 'kwoon_highlight', 'Highlight Colour', 'colors', '#4aa2d1', 10);
	$ebor_options->add_setting('color', 'kwoon_highlight_hover', 'Highlight Hover Colour', 'colors', '#358dbc', 15);
	$ebor_options->add_setting('color', 'kwoon_body', 'Body Text Colour', 'colors', '#606060', 20);
	$ebor_options->add_setting('color', 'kwoon_headings', 'Heading Text Colour', 'colors', '#404040', 25);
	$ebor_options->add_setting('color', 'kwoon_meta', 'Meta Text Colour', 'colors', '#9a9a9a', 30);
	$ebor_options->add_setting('color', 'kwoon_light_wrapper', 'Light Wrapper Background Colour', 'colors', '#fcfcfc', 35);
	$ebor_options->add_setting('color', 'kwoon_dark_wrapper', 'Dark Wrapper Background Colour', 'colors', '#f3f3f3', 40);
	$ebor_options->add_setting('color', 'kwoon_inverse_wrapper', 'Inverse Wrapper Background Colour', 'colors', '#262b2f', 45);
	$ebor_options->add_setting('color', 'kwoon_white', 'White Colour (Only modify if inverting colours completely)', 'colors', '#ffffff', 50);
	$ebor_options->add_setting('color', 'kwoon_black_wrapper', 'Black Wrapper Background Colour', 'colors', '#1f2124', 55);
	
	//Blog Options
	$ebor_options->add_setting('select', 'blog_layout', 'Blog Index Layout', 'blog_layout_section', 'classic', 10, $blog_layouts);
	$ebor_options->add_setting('input', 'blog_read_more', 'Blog Read More Text', 'blog_text_section', 'Read More', 20);
	$ebor_options->add_setting('input', 'blog_continue', 'Blog Continue Reading Text', 'blog_text_section', 'Continue Reading', 25);	
	$ebor_options->add_setting('input', 'blog_title', 'Blog Title', 'blog_text_section', 'Our Blog', 30);
	$ebor_options->add_setting('input', 'comments_title', 'Comments Title', 'blog_text_section', 'Would you like to share your thoughts?', 35);
	$ebor_options->add_setting('input', 'comments_subtitle', 'Comments Subtitle', 'blog_text_section', 'Your email address will not be published. Required fields are marked *', 40);
	$ebor_options->add_setting('input', 'author_details_title', 'Author Details Title', 'blog_text_section', 'About the author', 45);
	
	$ebor_options->add_setting('select', 'blog_page_title_layout', 'Blog Title Layout', 'blog_text_section', 'light', 55, $page_titles);
	$ebor_options->add_setting('image', 'blog_page_title_image', 'Blog Title Background', 'blog_text_section', '', 60);
	
	//Site options
	$ebor_options->add_setting('select', 'footer_popup_id', 'Footer Popup Layout (Uses content from selected page)', 'subfooter_settings_section', '', 10, $page_choices);
	
	$ebor_options->add_setting('select', 'disable_page_title', 'Disable page title bars sitewide?', 'site_section', 'no', 15, array('no' => 'No', 'yes' => 'Yes'));

	
	//Portfolio options
	$ebor_options->add_setting('select', 'portfolio_layout', 'Portfolio Layout', 'portfolio_layout_section', 'full', 10, $portfolio_layouts);
	$ebor_options->add_setting('select', 'portfolio_hover', 'What to display on portfolio item hover?', 'portfolio_layout_section', 'yes', 15, array('no' => 'Portfolio Post Title', 'yes' => 'View Project Text'));
	
	$ebor_options->add_setting('select', 'single_portfolio_related', 'Show Related Posts?', 'single_portfolio_layout_section', 'yes', 10, array('no' => 'No', 'yes' => 'Yes'));
	$ebor_options->add_setting('select', 'single_portfolio_sharing', 'Show Sharing Buttons?', 'single_portfolio_layout_section', 'yes', 15, array('no' => 'No', 'yes' => 'Yes'));
	
	$ebor_options->add_setting('input', 'portfolio_title', 'Portfolio Archives: Title', 'portfolio_text_section', 'From My Portfolio', 20);
	$ebor_options->add_setting('input', 'portfolio_view_project', 'Portfolio Archives: View Project', 'portfolio_text_section', 'View Project', 25);
	$ebor_options->add_setting('select', 'portfolio_page_title_layout', 'Portfolio Title Layout', 'portfolio_text_section', 'light', 45, $page_titles);
	$ebor_options->add_setting('image', 'portfolio_page_title_image', 'Portfolio Title Background', 'portfolio_text_section', '', 40);
	
	//Logo Options
	$ebor_options->add_setting('image', 'custom_logo', 'Logo', 'logo_settings_section', EBOR_THEME_DIRECTORY . 'style/images/logo.png', 5);
	$ebor_options->add_setting('image', 'custom_logo_retina', 'Retina Logo', 'logo_settings_section', EBOR_THEME_DIRECTORY . 'style/images/logo@2x.png', 10);
	$ebor_options->add_setting('image', 'custom_logo_dark', 'Dark Logo', 'logo_settings_section', EBOR_THEME_DIRECTORY . 'style/images/logo-dark.png', 15);
	$ebor_options->add_setting('image', 'custom_logo_dark_retina', 'Dark Retina Logo', 'logo_settings_section', EBOR_THEME_DIRECTORY . 'style/images/logo-dark@2x.png', 20);
	
	//Header Icons
	$ebor_options->add_setting('select', 'site_mode', 'Site Mode? (Single Page Enables URL rewriting)', 'site_section', 'multipage', 10, array('multipage' => 'Multi-Page', 'single-page' => 'Single-Page'));
	
	//Header Icons
	for( $i = 1; $i < 7; $i++ ){
		$ebor_options->add_setting('select', 'header_social_icon_' . $i, 'Header Social Icon ' . $i, 'header_icons_section', 'none', 20 + $i + $i, $social_options);
		$ebor_options->add_setting('input', 'header_social_url_' . $i, 'Header Social URL ' . $i, 'header_icons_section', '', 21 + $i + $i);
	}
	
	//footer Icons
	for( $i = 1; $i < 7; $i++ ){
		$ebor_options->add_setting('select', 'footer_social_icon_' . $i, 'Social Icon ' . $i, 'footer_icons_section', 'pinterest', 20 + $i + $i, $social_options);
		$ebor_options->add_setting('input', 'footer_social_url_' . $i, 'Social URL ' . $i, 'footer_icons_section', '', 21 + $i + $i);
	}
	
	//Footer Options
	$ebor_options->add_setting('textarea', 'copyright', 'Copyright Message', 'subfooter_settings_section', $footer_default, 20);
}